internal/typeparams: update MultiIndexExpr to IndexListExpr

This type was renamed in CL 348609, based on discussion in the
go/ast proposal.

Change-Id: I3addcf1bb192ad03f59f599a7aec68a579178fd5
Reviewed-on: https://go-review.googlesource.com/c/tools/+/348629
Trust: Robert Findley <rfindley@google.com>
Run-TryBot: Robert Findley <rfindley@google.com>
gopls-CI: kokoro <noreply+kokoro@google.com>
TryBot-Result: Go Bot <gobot@golang.org>
Reviewed-by: Robert Griesemer <gri@golang.org>
diff --git a/internal/typeparams/typeparams.go b/internal/typeparams/typeparams.go
index e263537..12a4e60 100644
--- a/internal/typeparams/typeparams.go
+++ b/internal/typeparams/typeparams.go
@@ -22,7 +22,7 @@
 // expressions.
 //
 // For an ast.IndexExpr, the resulting IndexExprData will have exactly one
 // index expression. For an ast.MultiIndexExpr (go1.18+), it may have a
 // variable number of index expressions.
 //
 // For nodes that don't represent index expressions, GetIndexExprData returns
@@ -36,7 +36,7 @@
 			Indices: []ast.Expr{e.Index},
 			Rbrack:  e.Rbrack,
 		}
-	case *ast.MultiIndexExpr:
+	case *ast.IndexListExpr:
 		return (*IndexExprData)(e)
 	}
 	return nil
@@ -22,7 +22,7 @@
 //
 // For an ast.IndexExpr, the resulting IndexExprData will have exactly one
-// index expression. For an ast.MultiIndexExpr (go1.18+), it may have a
+// index expression. For an ast.IndexListExpr (go1.18+), it may have a
 // variable number of index expressions.
 //